Package: ivygapSE
Title: A SummarizedExperiment for Ivy-GAP data
Description: Define a SummarizedExperiment and exploratory app for Ivy-GAP glioblastoma image, expression, and clinical data.
Version: 1.35.2
Author: Vince Carey
Suggests: knitr, png, limma, grid, DT, randomForest, digest, testthat,
        rmarkdown, BiocStyle, magick, statmod, codetools
Depends: R (>= 3.5.0), SummarizedExperiment, BiocFileCache
Imports: shiny, survival, hwriter, plotly, ggplot2, S4Vectors,
        graphics, stats, utils
Maintainer: VJ Carey <stvjc@channing.harvard.edu>
License: Artistic-2.0
LazyLoad: yes
biocViews: Transcription, Software, Visualization, Survival,
        GeneExpression, Sequencing
VignetteBuilder: knitr
Config/roxygen2/version: 8.0.0
Encoding: UTF-8
git_url: https://git.bioconductor.org/packages/ivygapSE
git_branch: devel
git_last_commit: e705549
git_last_commit_date: 2026-06-22
Repository: Bioconductor 3.24
Date/Publication: 2026-06-22
NeedsCompilation: no
Packaged: 2026-06-22 22:29:51 UTC; biocbuild
