# Generated by roxygen2: do not edit by hand

export(designOverview)
export(exprByType)
export(getRefLimma)
export(ivyGlimpse)
export(makeGeneSets)
export(nomenclat)
export(subBlockDetails)
export(tumorDetails)
export(vocab)
import(SummarizedExperiment)
import(ggplot2, except=last_plot)
import(hwriter)
import(plotly)
import(shiny)
import(survival)
importFrom(S4Vectors,metadata)
importFrom(graphics,axis)
importFrom(graphics,barplot)
importFrom(graphics,boxplot)
importFrom(graphics,legend)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(stats,median)
importFrom(utils,browseURL)
importFrom(utils,data)
importFrom(utils,download.file)
importFrom(utils,packageVersion)
